%define anolis_release 1
%bcond_without python3

Name:          tbb
Summary:       The Threading Building Blocks library abstracts low-level threading details
Version:       2021.5.0
Release:       %{anolis_release}%{?dist}
License:       ASL 2.0
URL:           http://threadingbuildingblocks.org/

Source0:       https://github.com/intel/tbb/archive/v%{version}.tar.gz

BuildRequires: cmake
BuildRequires: doxygen
BuildRequires: gcc-c++
BuildRequires: make
BuildRequires: python3-devel
BuildRequires: hwloc-devel
BuildRequires: swig

%description
Threading Building Blocks (TBB) is a C++ runtime library that
abstracts the low-level threading details necessary for optimal
multi-core performance.  It uses common C++ templates and coding style
to eliminate tedious threading implementation work.

TBB requires fewer lines of code to achieve parallelism than other
threading models.  The applications you write are portable across
platforms.  Since the library is also inherently scalable, no code
maintenance is required as more processor cores become available.


%package devel
Summary: The Threading Building Blocks C++ headers and shared development libraries
Requires: %{name} = %{version}-%{release}

%description devel
Header files and shared object symlinks for the Threading Building
Blocks (TBB) C++ libraries.


%package doc
Summary: The Threading Building Blocks documentation
Provides: bundled(jquery)

%description doc
PDF documentation for the user of the Threading Building Block (TBB)
C++ library.


%package -n python3-%{name}
Summary: Python 3 TBB module

%description -n python3-%{name}
Python 3 TBB module.


%prep
%autosetup -n oneTBB-%{version} -p1

# Invoke the right python binary directly
sed -i 's/version\s*="0.2"/version = "%{version}"/' python/setup.py
sed -i '1{/^#!.*env python/ d}' python/TBB.py python/tbb/*.py

%build
%cmake \
%if ! %{with test}
  -DTBB_TEST:BOOL=OFF \
%endif
%if %{with python3}
  -DTBB4PY_BUILD:BOOL=ON \
%endif

%cmake_build	

# Build for python 3
pushd python
cp ../anolis-linux-build/gnu_12.1_cxx11_64_relwithdebinfo/libirml.so* ./
cp ../anolis-linux-build/gnu_12.1_cxx11_64_relwithdebinfo/libtbb.so* ./
%py3_build
popd


%install
mkdir -p anolis-linux-build/python/build
%cmake_install

mkdir %{buildroot}/%{_includedir}/rml
install -m 0644 -p src/tbb/rml_*.h %{buildroot}/%{_includedir}/rml 

# Python 3 install
pushd python
%py3_install
popd


%files
%license LICENSE.txt
%{_libdir}/libtbb.so.12*
%{_libdir}/libtbbmalloc.so.2*
%{_libdir}/libtbbmalloc_proxy.so.2*
%{_libdir}/libirml.so.1*
%{_libdir}/libtbbbind_2_5.so.3*

%files devel
%{_includedir}/tbb/
%{_includedir}/rml/
%{_includedir}/oneapi/
%{_libdir}/*.so
%{_libdir}/cmake/TBB/
%{_libdir}/pkgconfig/*.pc

%files doc
%doc README.md CONTRIBUTING.md Bazel.md
%doc third-party-programs.txt
%doc cmake/README.md
%{_datadir}/doc/TBB/README.md

%files -n python3-%{name}
%doc python/README.md
%{python3_sitearch}/TBB*
%{python3_sitearch}/tbb/
%{python3_sitearch}/__pycache__/TBB*

%changelog
* Tue Jul 26 2022 happy_orange <songnannan@linux.alibaba.com> - 2021.5.0-1
- Init pcakage from upstream
